hotspot/src/share/vm/services/heapDumper.cpp
changeset 35492 c8c0273e6b91
parent 33794 41ef3dc95179
child 35528 f8a8d6664a19
--- a/hotspot/src/share/vm/services/heapDumper.cpp	Thu Jan 14 09:18:11 2016 +0100
+++ b/hotspot/src/share/vm/services/heapDumper.cpp	Thu Jan 14 13:26:19 2016 +0100
@@ -1708,10 +1708,10 @@
   CollectedHeap* ch = Universe::heap();
 
   ch->ensure_parsability(false); // must happen, even if collection does
                                  // not happen (e.g. due to GC_locker)
 
   if (_gc_before_heap_dump) {
-    if (GC_locker::is_active()) {
+    if (GCLocker::is_active()) {
       warning("GC locker is held; pre-heapdump GC was skipped");
     } else {
       ch->collect_as_vm_thread(GCCause::_heap_dump);
@@ -1708,10 +1708,10 @@
 
   ch->ensure_parsability(false); // must happen, even if collection does
-                                 // not happen (e.g. due to GC_locker)
+                                 // not happen (e.g. due to GCLocker)
 
   if (_gc_before_heap_dump) {